@@ -69,8 +69,9 @@ class Parser:
         
         if tagName.startswith('event'):
             name = dom.attr('v')
+            param = dom.attr('param')
             f = getattr(self.events, name)
-            return self.EventObj(tagName.replace('event-', ''), f)
+            return self.EventObj(tagName.replace('event-', ''), param, f)
 
         e = self.ElementObj(self, parent, tagName, dom)
         l = list(map(lambda c: self.loopChild(c, e), dom.children()))
